@@ -30,7 +30,7 @@ type session struct {
 }
 
 type pluginConfig struct {
-	plugin.SystemOptions `conf:"optional,name=System"`
+	System plugin.SystemOptions `conf:"optional"` //nolint:staticcheck
 	// Timeout is the amount of time to wait for a server to respond when
 	// first connecting and on follow up operations in the session.
 	Timeout int `conf:"optional,range=1:30,default=3"`
@@ -48,7 +48,7 @@ type pluginConfig struct {
 func (p *emberPlugin) Configure(global *plugin.GlobalOptions, options any) {
 	pConfig := &pluginConfig{}
 
-	err := conf.Unmarshal(options, pConfig)
+	err := conf.UnmarshalStrict(options, pConfig)
 	if err != nil {
 		p.Errf("cannot unmarshal configuration options: %s", err.Error())
 
@@ -67,7 +67,7 @@ func (p *emberPlugin) Configure(global *plugin.GlobalOptions, options any) {
 func (*emberPlugin) Validate(options any) error {
 	var opts pluginConfig
 
-	err := conf.Unmarshal(options, &opts)
+	err := conf.UnmarshalStrict(options, &opts)
 	if err != nil {
 		return errs.Wrap(err, "failed to unmarshal configuration options")
 	}
